% Quokka3 settingsfile for a PERC cell of Trina Solar
% calibrated to production-line cells during ramp-up
% published at Silicon PV 2018: Detailed 3D Full-Cell Modeling in Quokka3: Quantifying Edge and Solder-Pad Losses in an Industrial PERC Cell
% and JPV 2018: A Detailed Full-Cell Model of a 2018 Commercial PERC Solar Cell in Quokka3
% Andreas Fell + Pietro Altermatt
% (c) 2021 Andreas Fell

% busbar-enhanced unit-cell version

Syntax = 'front and rear contact unit cell';

UnitCellType = 'busbar-enhanced';
CellThickness = 170;

FrontContactShape = 'line';
FrontMetalShape = 'H-pattern';
FrontContactPitch = 1500; % originally 1498, slightly adjusted for low lcm with rear pitch
FrontFingerWidth = 60;
FrontFingerShadingFraction = 0.8;
FrontContactWidth = 60;
FrontContact.OhmicResistivity = 2.7e-3; 

RearContactShape = 'dash';
RearMetalShape = 'full';
RearContact.OhmicResistivity = 3e-3;
RearContactPitch = 1000; % originally 1010, slightly adjusted for low lcm with front pitch
RearContactWidth = 72.6;
RearContactSpacing = 1000;
RearContactLength = 800;

% busbar settings
BusbarPitch = 31.35 mm;
FrontBusbarWidth = 800; 
RearBusbarWidth = 1100; % width of rear Ag pads, half of actual 2.2mm thickness, as the stripes only cover ~50% of the cell length
FrontBusbarContactEnable = 0; % results in the front contact lines (i.e. laser contact opening) also being present underneath the busbar
RearBusbarContactEnable = 1; % rear busbar contact needs to be enabled to override the dashed contacts by a very high contact resistivity and this effectively disables the contacts underneath the rear busbar
RearBusbarContact.OhmicResistivity = 1e10;
FrontMetalRsheet = 0.003;
RearMetalRsheet = 0.0175;

FrontMetalPolarity = 'n-type';
RearMetalPolarity = 'p-type';

Solver.SolutionType = 'light JV-curve';
% Solver.QECurve.Type = 'biased';
% Solver.QECurve.Side = 'front';
% Solver.QECurve.JgenMonochromatic = 0.1;
% Solver.QECurve.WavelengthStepSize = 'coarse';
Solver.Electrical.MetalModelType = 'finite-differences';
Solver.Electrical.SkinJ0nieff.Type = 'user-T';
Solver.Electrical.SkinJ0nieff.T = 298.15;

ExternalCircuit.Enable = 1;
ExternalCircuit.Rseries = 0.06; % [Ohm.cm2]
ExternalCircuit.Rshunt = 1e10; % [Ohm.cm2]
ExternalCircuit.DiodeJ0 = 0; % [A/cm2]
ExternalCircuit.DiodeIdeality = 1; % []


Optical.GenerationModelType = 'Text-Z';
Optical.FrontIllumination.Enable = 1;
Optical.FrontIllumination.Spectrum.Type = 'AM1.5g';
Optical.FrontIllumination.Scale = 1;
Optical.RearIllumination.Enable = 0;
Optical.TextZ.FrontText.Type = 'Text';
Optical.TextZ.FrontText.Text.Type = 'file';
Optical.TextZ.FrontText.Text.File = 'Trina_PERC_Text.csv';
Optical.TextZ.FrontText.FacetAngle = 54;
Optical.TextZ.FrontZ.Type = 'local'; % calculates Z locally from internal optical properties of the skins
Optical.ScaleGeneration = 1;

Thermal.T = 298.15;

Bulk.BackgroundDoping.SettingType = 'dopingtype-resistivity';
Bulk.BackgroundDoping.DopingType = 'p-type';
Bulk.BackgroundDoping.Resistivity = 1.5;
Bulk.Electrical.Recombination.Type = 'intrinsic plus SRH';
Bulk.Electrical.Recombination.SRH(1).Type = 'tau-Et';
Bulk.Electrical.Recombination.SRH(1).taun = 150;
Bulk.Electrical.Recombination.SRH(1).taup = 750;
Bulk.Electrical.Recombination.SRH(1).Et_Ei = 0;


FullFrontSkin.ElectricalModelType = 'lumped';
FullFrontSkin.Lumped.Electrical.RsheetEnable = 1;
FullFrontSkin.Lumped.Electrical.Rsheet = 148.8;
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
FullFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 30.7e-15;
FullFrontSkin.OpticalModelType = 'lumped';
FullFrontSkin.Lumped.Optical.Internal.Rint = 0.92;
FullFrontSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalFrontSkin.Enable = 1;
LocalFrontSkin.Width = 300;
LocalFrontSkin.ElectricalModelType = 'lumped';
LocalFrontSkin.Geometry.DepthType = 'user';
LocalFrontSkin.Geometry.DepthUser = 0.66;
LocalFrontSkin.Lumped.Electrical.RsheetEnable = 1;
LocalFrontSkin.Lumped.Electrical.Rsheet = 58.5;
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.ContactedRecombination.J0 = 500e-15;
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'J0';
LocalFrontSkin.Lumped.Electrical.NonContactedRecombination.J0 = 120e-15;
LocalFrontSkin.Lumped.Electrical.EtaColl = 0.882; % depth and collection efficiency from detailed modeling @400nm
LocalFrontSkin.OpticalModelType = 'lumped';
LocalFrontSkin.Lumped.Optical.Internal.Rint = 0.9;
LocalFrontSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalFrontContactSkin.Enable = 1;
LocalFrontContactSkin.ElectricalModelType = 'lumped';
LocalFrontContactSkin.Lumped.Electrical.RsheetEnable = 1;
LocalFrontContactSkin.Lumped.Electrical.Rsheet = 58.5;
LocalFrontContactSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalFrontContactSkin.Lumped.Electrical.ContactedRecombination.J0 = 500e-15;
% for lack of other data using passivated internal optical properties
LocalFrontContactSkin.OpticalModelType = 'lumped';
LocalFrontContactSkin.Lumped.Optical.Internal.Rint = 0.85;
LocalFrontContactSkin.Lumped.Optical.Internal.Diffuse = 1;


FullRearSkin.ElectricalModelType = 'lumped';
FullRearSkin.Lumped.Electrical.RsheetEnable = 0;
FullRearSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'Seff';
FullRearSkin.Lumped.Electrical.NonContactedRecombination.Seff = 10;
% internal optics from fit to raytracing results
FullRearSkin.OpticalModelType = 'lumped';
FullRearSkin.Lumped.Optical.Internal.Rint = 0.98;
FullRearSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalRearContactSkin.Enable = 1;
LocalRearContactSkin.ElectricalModelType = 'lumped';
LocalRearContactSkin.Lumped.Electrical.RsheetEnable = 1;
LocalRearContactSkin.Lumped.Electrical.Rsheet = 60; % doesn't matter
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'J0';
LocalRearContactSkin.Lumped.Electrical.ContactedRecombination.J0 = 400e-15;
% internal optics from fit to raytracing results
LocalRearContactSkin.OpticalModelType = 'lumped';
LocalRearContactSkin.Lumped.Optical.Internal.Rint = 0.89;
LocalRearContactSkin.Lumped.Optical.Internal.Diffuse = 1;

LocalRearBusbarSkin.Enable = 1;
LocalRearBusbarSkin.ElectricalModelType = 'lumped';
LocalRearBusbarSkin.Lumped.Electrical.RsheetEnable = 1;
LocalRearBusbarSkin.Lumped.Electrical.Rsheet = 1e10;
LocalRearBusbarSkin.Lumped.Electrical.NonContactedRecombination.ModelType = 'Seff';
LocalRearBusbarSkin.Lumped.Electrical.NonContactedRecombination.Seff = 10;
LocalRearBusbarSkin.Lumped.Electrical.ContactedRecombination.ModelType = 'Seff';
LocalRearBusbarSkin.Lumped.Electrical.ContactedRecombination.Seff = 10;
% internal optics from fit to raytracing results
LocalRearBusbarSkin.OpticalModelType = 'lumped';
LocalRearBusbarSkin.Lumped.Optical.Internal.Rint = 1;
LocalRearBusbarSkin.Lumped.Optical.Internal.Diffuse = 1;

